| Title: | Gentle Language Installer for R User |
|---|---|
| Description: | Provides install functions of other languages such as 'java', 'python'. |
| Authors: | Chanyub Park [aut, cre] (ORCID: <https://orcid.org/0000-0001-6474-2570>) |
| Maintainer: | Chanyub Park <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.4 |
| Built: | 2026-05-22 09:31:52 UTC |
| Source: | https://github.com/mrchypark/multilinguer |
jdk
Install openjdk which is one of openjdk(java) distro.
Case of MacOS, remove all java and reinstall corretto version 11.
install_jdk( path = jdk_path(), version = "11", gui = TRUE, run = "ask", force = FALSE ) install_java( path = jdk_path(), version = "11", gui = TRUE, run = "ask", force = FALSE )install_jdk( path = jdk_path(), version = "11", gui = TRUE, run = "ask", force = FALSE ) install_java( path = jdk_path(), version = "11", gui = TRUE, run = "ask", force = FALSE )
path |
String; The location where jdk is (or should be) installed. See
jdk_path for more details on the default path used by |
version |
String; Jdk version. Now only support "11". check inst/jdk.yaml. |
gui |
Boolean; Some jdk supports os native installer. User can use
the gui when in interactive mode and use |
run |
c("ask","yes","no");If set "yes", installation proccess start. Default is "ask" to user. |
force |
Boolean; force install when is TRUE. Default is FALSE. |
Other jdk-installer:
jdk_path(),
remove_jdk()
Other jdk-installer:
jdk_path(),
remove_jdk()
## Not run: install_java() install_jdk() ## End(Not run)## Not run: install_java() install_jdk() ## End(Not run)
java available check
java_available() jdk_available()java_available() jdk_available()
java_available()java_available()
The path to the Jdk installation to use. By default, an OS-specific
path is used. If you'd like to instead set your own path, you can set the
MULTILINGUER_JDK_PATH environment variable.
jdk_path()jdk_path()
You need to make sure you have permission when setting the path with MULTILINGUER_JDK_PATH.
Other jdk-installer:
install_jdk(),
remove_jdk()
jdk_path()jdk_path()
Uninstall jdk from this package.
remove_jdk(path = jdk_path()) uninstall_jdk(path = jdk_path())remove_jdk(path = jdk_path()) uninstall_jdk(path = jdk_path())
path |
The path in which jdk is installed. |
Other jdk-installer:
install_jdk(),
jdk_path()
Other jdk-installer:
install_jdk(),
jdk_path()
## Not run: remove_jdk() uninstall_jdk() ## End(Not run)## Not run: remove_jdk() uninstall_jdk() ## End(Not run)